@@ -590,13 +590,29 @@ PCSC_API p_SCardTransmit(SCardTransmit)
 
 	Enter();
 	spy_long(hCard);
-	spy_long(pioSendPci->dwProtocol);
-	spy_long(pioSendPci->cbPciLength);
+	if (pioSendPci)
+	{
+		spy_long(pioSendPci->dwProtocol);
+		spy_long(pioSendPci->cbPciLength);
+	}
+	else
+	{
+		spy_long(-1);
+		spy_long(-1);
+	}
 	spy_buffer(pbSendBuffer, cbSendLength);
 	rv = spy.SCardTransmit(hCard, pioSendPci, pbSendBuffer, cbSendLength,
 		pioRecvPci, pbRecvBuffer, pcbRecvLength);
-	spy_long(pioRecvPci->dwProtocol);
-	spy_long(pioRecvPci->cbPciLength);
+	if (pioRecvPci)
+	{
+		spy_long(pioRecvPci->dwProtocol);
+		spy_long(pioRecvPci->cbPciLength);
+	}
+	else
+	{
+		spy_long(-1);
+		spy_long(-1);
+	}
 	if (pcbRecvLength)
 		spy_buffer(pbRecvBuffer, *pcbRecvLength);
 	else
